@@ -552,7 +552,7 @@ class DecisionTreeBucketer(BaseBucketer):
         max_n_bins=100,
         missing_treatment="separate",
         min_bin_size=0.05,
-        random_state=42,
+        random_state=None,
         remainder="passthrough",
         dt_kwargs={},
     ) -> None:
@@ -567,7 +567,7 @@ class DecisionTreeBucketer(BaseBucketer):
                 This dictionary contains a name of a bucket (key) and an array of unique values that should be put
                 in that bucket.
                 When special values are defined, they are not considered in the fitting procedure.
-            min_bin_size (int): Minimum fraction of observations in a bucket. Passed directly to min_samples_leaf.
+            min_bin_size (float): Minimum fraction of observations in a bucket. Passed directly to min_samples_leaf.
             max_n_bins (int): Maximum numbers of after the bucketing. Passed directly to max_leaf_nodes of the
                 DecisionTreeClassifier.
                 If specials are defined, max_leaf_nodes will be redefined to max_n_bins - (number of special bins).
@@ -600,6 +600,7 @@ class DecisionTreeBucketer(BaseBucketer):
         self.min_bin_size = min_bin_size
         self.random_state = random_state
         self.remainder = remainder
+        self.dt_kwargs.update({"random_state": self.random_state})
 
         check_args(dt_kwargs, DecisionTreeClassifier)
 
@@ -650,7 +651,6 @@ class DecisionTreeBucketer(BaseBucketer):
             binner = DecisionTreeClassifier(
                 max_leaf_nodes=(self.max_n_bins - n_special_bins),
                 min_samples_leaf=min_bin_size,
-                random_state=self.random_state,
                 **self.dt_kwargs,
             )
             binner.fit(X.values.reshape(-1, 1), y)
@@ -796,7 +796,7 @@ class OrdinalCategoricalBucketer(BaseBucketer):
             cats = X_y.groupby([feature])["target"].mean().sort_values(ascending=True).index
             normalized_counts = normalized_counts[cats]
 
-        if self.encoding_method == "frequency":
+        elif self.encoding_method == "frequency":
             normalized_counts = X_y[feature].value_counts(normalize=True)
 
         # Limit number of categories if set.
