@@ -2,6 +2,7 @@
 from .report import build_bucket_table, psi, iv
 from .plotting import (
     plot_bucket_table,
+    weight_plot
 )
 
-__all__ = ["build_bucket_table", "plot_bucket_table", "psi", "iv"]
+__all__ = ["build_bucket_table", "plot_bucket_table", "psi", "iv", "weight_plot"]
